#import <objectbase/SwarmObject.h>
#import "Hashtable.h"
#import "MemLogConsumer.h"

// KISS stands for Keep it simple, stupid.

@interface KISSMemLogger : SwarmObject <MemLogConsumer>
{
	Hashtable* myObjects;  // would need a lib from GNUstep for a hashtable
	id <List> myTexts;
	id myCanvas;
	int updateEvery, isCanvasDestroyed, lastTime;
}

+create: aZone updateEvery: (int) p;
-(void)consumeRecordTime: (timeval_t) aTime alloc: (int) i\
   classname: (char*) cname address: (void*) addr size: (long) size;
-update; // update display yourself when updateFrequency==0
@end
